@@ -5,6 +5,7 @@
 #include <QMessageBox>
 #include <QPair>
 #include <QList>
+#include <QSettings>
 #include <QtNetwork/QTcpServer>
 #include <QtNetwork/QTcpSocket>
 #include <QtNetwork/QHostAddress>
@@ -19,6 +20,7 @@
 #include "protocol.h"
 #include "utils.h"
 #include "reversidefs.h"
+#include "optionsdialog.h"
 
 CentralWidget::CentralWidget(QWidget *parent, ReversiGame &reversiGame):
     QWidget(parent),
@@ -28,8 +30,11 @@ CentralWidget::CentralWidget(QWidget *parent, ReversiGame &reversiGame):
     isNetworkGame_(false),
     reversiGame_(reversiGame)
 {
+    //readSettings();
+
     layout_ = new QGridLayout(this);
     fieldView_ = new FieldView(reversiGame_, this);
+    fieldView_->setAnimationSpeed(settings_.animationSpeed());
     layout_->addWidget(fieldView_, 0, 0);
 
     infoLayout_ = new QVBoxLayout();
@@ -37,12 +42,14 @@ CentralWidget::CentralWidget(QWidget *parent, ReversiGame &reversiGame):
     infoPanel_ = new InfoPanel(reversiGame_, this);
     infoLayout_->addWidget(infoPanel_);
 
-    modePanel_ = new ModePanel(this);
+    modePanel_ = new ModePanel(this, settings_.mode(), settings_.AILevel());
     infoLayout_->addWidget(modePanel_);
     infoLayout_->addStretch(1);
 
     layout_->addItem(infoLayout_, 0, 1);
 
+
+
     showInfoPanels();
 
     connect(&reversiGame_, SIGNAL(stepUnavailable()), SLOT(stepUnavailable()));
@@ -54,6 +61,17 @@ CentralWidget::CentralWidget(QWidget *parent, ReversiGame &reversiGame):
     connect(gameClient_, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(displayP2PError(QAbstractSocket::SocketError)));
 }//ctor
 
+CentralWidget::~CentralWidget()
+{
+    //saveSettings();
+    if (settings_.saveMode())
+    {
+        QPair<int, int> mode = modePanel_->mode();
+        settings_.setMode(mode.first);
+        settings_.setAILevel(mode.second);
+    }
+}
+
 void CentralWidget::slotOrientationChanged()
 {
     showInfoPanels();
@@ -264,3 +282,9 @@ void CentralWidget::displayP2PError(QAbstractSocket::SocketError socketError)
     }
 }//displayP2PError
 
+void CentralWidget::slotOptions()
+{
+    OptionsDialog optDlg(&settings_, parentWidget());
+    if (optDlg.exec() == QDialog::Accepted)
+        fieldView_->setAnimationSpeed(settings_.animationSpeed());
+}
