@@ -5,6 +5,7 @@
 #include <QtNetwork/QTcpSocket>
 
 #include "reversigame.h"
+#include "qthellosettings.h"
 
 enum P2PSTATE {WAIT_SERVER_VERSION, WAIT_CLIENT_VERSION, WAIT_SERVER_NEW_GAME, RUNNING, SERVER_PAUSED, CLIENT_PAUSED};
 
@@ -21,15 +22,14 @@ class CentralWidget : public QWidget
     Q_OBJECT
 public:
     explicit CentralWidget(QWidget *parent, ReversiGame &reversiGame);
+    ~CentralWidget();
     void showInfoPanels();
-    /** 
-     * @brief Starts new game
-     */
-    void newGame();
 
 private:
     bool newGameP2PServer();
     bool newGameP2PClient();
+    void readSettings();
+    void saveSettings();
 
 private:
     QGridLayout *layout_;
@@ -47,8 +47,15 @@ private:
 
     ReversiGame &reversiGame_;
 
+    QthelloSettings settings_;
+
 public slots:
+    /**
+     * @brief Starts new game
+     */
+    void newGame();
     void slotPlayerStep(int x, int y);
+    void slotOptions();
 
 private slots:
     void stepUnavailable();
