@@ -14,17 +14,20 @@
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent)
 {
+    QCoreApplication::setOrganizationName("XBASoft");
+    QCoreApplication::setApplicationName("Qthello");
+
     setWindowTitle(tr("Qthello"));
     centralWdgt = new CentralWidget(this, reversiGame_);
     setCentralWidget(centralWdgt);
     createMenuToolbar();
+
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 #endif
 
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(slotOrientationChanged()));
     connect(&reversiGame_, SIGNAL(gameOver()), SLOT(slotGameOver()));
-
     slotNewGame();
 }
 
@@ -45,6 +48,10 @@ void MainWindow::createMenuToolbar()
     a->setShortcut(Qt::ALT + Qt::Key_X);
     connect(a, SIGNAL(triggered()), this, SLOT(close()));
 
+    mn = menuBar()->addMenu(tr("&Options"));
+    a = mn->addAction(tr("&Options..."));
+    connect(a, SIGNAL(triggered()), centralWdgt, SLOT(slotOptions()));
+
     mn = menuBar()->addMenu(tr("&Help"));
     a = mn->addAction(tr("&About..."));
     connect(a, SIGNAL(triggered()), this, SLOT(slotAbout()));
