@@ -37,7 +37,7 @@ signals:
     void stepComplete();
     void stepImpossible();
     void updateInfo();
-    void newGame(bool);
+    void newGame(int);
     void gameOver();
     void stepUnavailable();
 
